rpms/rgmanager/F-9 kernel-2.6.25.diff, NONE, 1.1 userland-2.6.26.diff, NONE, 1.1 .cvsignore, 1.17, 1.18 rgmanager.spec, 1.47, 1.48 sources, 1.26, 1.27

Fabio M. Di Nitto (fabbione) fedora-extras-commits at redhat.com
Thu Aug 14 12:40:07 UTC 2008


Author: fabbione

Update of /cvs/pkgs/rpms/rgmanager/F-9
In directory cvs-int.fedora.redhat.com:/tmp/cvs-serv347

Modified Files:
	.cvsignore rgmanager.spec sources 
Added Files:
	kernel-2.6.25.diff userland-2.6.26.diff 
Log Message:
New upstream release


kernel-2.6.25.diff:

--- NEW FILE kernel-2.6.25.diff ---
diff -Naurd cluster-2.03.07.orig/gfs-kernel/src/gfs/ops_address.c cluster-2.03.07/gfs-kernel/src/gfs/ops_address.c
--- cluster-2.03.07.orig/gfs-kernel/src/gfs/ops_address.c	2008-08-12 16:14:36.000000000 +0200
+++ cluster-2.03.07/gfs-kernel/src/gfs/ops_address.c	2008-08-14 12:39:08.000000000 +0200
@@ -404,7 +404,7 @@
 		if (inode->i_size < file_size)
 			i_size_write(inode, file_size);
 	} else {
-		error = block_commit_write(page, from, to);
+		error = generic_commit_write(file, page, from, to);
 		if (error)
 			goto fail;
 	}
diff -Naurd cluster-2.03.07.orig/gfs-kernel/src/gfs/quota.c cluster-2.03.07/gfs-kernel/src/gfs/quota.c
--- cluster-2.03.07.orig/gfs-kernel/src/gfs/quota.c	2008-08-12 16:14:36.000000000 +0200
+++ cluster-2.03.07/gfs-kernel/src/gfs/quota.c	2008-08-14 12:39:08.000000000 +0200
@@ -947,8 +947,8 @@
 
 	if (current->signal) {
 		tty = current->signal->tty;
-		if (tty && tty->ops->write)
-			tty->ops->write(tty, line, len);
+		if (tty && tty->driver->write)
+			tty->driver->write(tty, line, len);
 	}
 
 	kfree(line);
diff -Naurd cluster-2.03.07.orig/gnbd-kernel/src/gnbd.c cluster-2.03.07/gnbd-kernel/src/gnbd.c
--- cluster-2.03.07.orig/gnbd-kernel/src/gnbd.c	2008-08-12 16:14:36.000000000 +0200
+++ cluster-2.03.07/gnbd-kernel/src/gnbd.c	2008-08-14 12:38:51.000000000 +0200
@@ -56,25 +56,26 @@
 
 #define to_gnbd_dev(d) container_of(d, struct gnbd_device, class_dev)
 
-static void gnbd_class_release(struct device *class_dev)
+static void gnbd_class_release(struct class_device *class_dev)
 {
 	/* FIXME -- What the hell do I have to free up here */
 }
 
 static struct class gnbd_class = {
 	.name = "gnbd",
-	.dev_release = gnbd_class_release
+	.release = gnbd_class_release
 };
 
-static ssize_t show_pid(struct device *class_dev, struct device_attribute *attr, char *buf)
+
+static ssize_t show_pid(struct class_device *class_dev, char *buf)
 {
 	struct gnbd_device *dev = to_gnbd_dev(class_dev);
 	return sprintf(buf, "%d\n", dev->receiver_pid);
 }
 
-DEVICE_ATTR(pid, S_IRUGO, show_pid, NULL);
+static CLASS_DEVICE_ATTR(pid, S_IRUGO, show_pid, NULL);
 
-static ssize_t show_server(struct device *class_dev, struct device_attribute *attr, char *buf)
+static ssize_t show_server(struct class_device *class_dev, char *buf)
 {
 	struct gnbd_device *dev = to_gnbd_dev(class_dev);
 	if (dev->server_name)
@@ -85,7 +86,7 @@
 }
 
 /* FIXME -- should a empty store free the memory */
-static ssize_t store_server(struct device *class_dev, struct device_attribute *attr,
+static ssize_t store_server(struct class_device *class_dev,
 		const char *buf, size_t count)
 {
 	int res;
@@ -115,15 +116,15 @@
 	return count;
 }
 
-DEVICE_ATTR(server, S_IRUGO | S_IWUSR, show_server, store_server);
+CLASS_DEVICE_ATTR(server, S_IRUGO | S_IWUSR, show_server, store_server);
 
-static ssize_t show_name(struct device *class_dev, struct device_attribute *attr, char *buf)
+static ssize_t show_name(struct class_device *class_dev, char *buf)
 {
 	struct gnbd_device *dev = to_gnbd_dev(class_dev);
 	return sprintf(buf, "%s\n", dev->name);
 }
 
-static ssize_t store_name(struct device *class_dev, struct device_attribute *attr,
+static ssize_t store_name(struct class_device *class_dev,
                 const char *buf, size_t count)
 {
 	int res;
@@ -137,17 +138,17 @@
 	return count;
 }
 
-DEVICE_ATTR(name, S_IRUGO | S_IWUSR, show_name, store_name);
+CLASS_DEVICE_ATTR(name, S_IRUGO | S_IWUSR, show_name, store_name);
 
 
-static ssize_t show_sectors(struct device *class_dev, struct device_attribute *attr, char *buf)
+static ssize_t show_sectors(struct class_device *class_dev, char *buf)
 {
 	struct gnbd_device *dev = to_gnbd_dev(class_dev);
 	return sprintf(buf, "%Lu\n",
 			(unsigned long long)get_capacity(dev->disk));
 }
 
-static ssize_t store_sectors(struct device *class_dev, struct device_attribute *attr,
+static ssize_t store_sectors(struct class_device *class_dev,
 		const char *buf, size_t count)
 {
 	int res;
@@ -176,23 +177,23 @@
 	return count;
 }
 
-DEVICE_ATTR(sectors, S_IRUGO | S_IWUSR, show_sectors, store_sectors);
+CLASS_DEVICE_ATTR(sectors, S_IRUGO | S_IWUSR, show_sectors, store_sectors);
 
-static ssize_t show_usage(struct device *class_dev, struct device_attribute *attr, char *buf)
+static ssize_t show_usage(struct class_device *class_dev, char *buf)
 {
 	struct gnbd_device *dev = to_gnbd_dev(class_dev);
 	return sprintf(buf, "%d\n", dev->open_count);
 }
 
-DEVICE_ATTR(usage, S_IRUGO, show_usage, NULL);
+CLASS_DEVICE_ATTR(usage, S_IRUGO, show_usage, NULL);
 
-static ssize_t show_flags(struct device *class_dev, struct device_attribute *attr, char *buf)
+static ssize_t show_flags(struct class_device *class_dev, char *buf)
 {
 	struct gnbd_device *dev = to_gnbd_dev(class_dev);
 	return sprintf(buf, "0x%04x\n", dev->flags);
 }
 
-static ssize_t store_flags(struct device *class_dev, struct device_attribute *attr,
+static ssize_t store_flags(struct class_device *class_dev,
                 const char *buf, size_t count)
 {
 	int res;
@@ -208,9 +209,9 @@
 }
 
 
-DEVICE_ATTR(flags, S_IRUGO | S_IWUSR, show_flags, store_flags);
+CLASS_DEVICE_ATTR(flags, S_IRUGO | S_IWUSR, show_flags, store_flags);
 
-static ssize_t show_waittime(struct device *class_dev, struct device_attribute *attr, char *buf)
+static ssize_t show_waittime(struct class_device *class_dev, char *buf)
 {
 	struct gnbd_device *dev = to_gnbd_dev(class_dev);
 	if (list_empty(&dev->queue_head))
@@ -219,15 +220,15 @@
 			((long)jiffies - (long)dev->last_received) / HZ);
 }
 
-DEVICE_ATTR(waittime, S_IRUGO, show_waittime, NULL);
+CLASS_DEVICE_ATTR(waittime, S_IRUGO, show_waittime, NULL);
 
-static ssize_t show_connected(struct device *class_dev, struct device_attribute *attr, char *buf)
+static ssize_t show_connected(struct class_device *class_dev, char *buf)
 {
 	struct gnbd_device *dev = to_gnbd_dev(class_dev);
 	return sprintf(buf, "%d\n", (dev->sock != NULL));
 }
 
-DEVICE_ATTR(connected, S_IRUGO, show_connected, NULL);
+CLASS_DEVICE_ATTR(connected, S_IRUGO, show_connected, NULL);
 
 #ifndef NDEBUG
 static const char *ioctl_cmd_to_ascii(int cmd)
@@ -957,7 +958,7 @@
 	gnbd_cmd(&ping_req) = GNBD_CMD_PING;
 	ping_req.sector = 0;
 	ping_req.nr_sectors = 0;
-
+	
 	for (i = 0; i < MAX_GNBD; i++) {
 		struct gendisk *disk = alloc_disk(1);
 		if (!disk)
@@ -1013,35 +1014,35 @@
 		init_waitqueue_head(&gnbd_dev[i].tx_wait);
 		gnbd_dev[i].current_request = NULL;
 		gnbd_dev[i].class_dev.class = &gnbd_class;
-		sprintf(gnbd_dev[i].class_dev.bus_id, "gnbd%d", i);
-		err = device_register(&gnbd_dev[i].class_dev);
+		sprintf(gnbd_dev[i].class_dev.class_id, "gnbd%d", i);
+		err = class_device_register(&gnbd_dev[i].class_dev);
 		if (err){
-			printk("device_register failed with %d\n", err);
+			printk("class_device_register failed with %d\n", err);
 			goto out_unregister_class;
 		}
-		if(device_create_file(&gnbd_dev[i].class_dev,
-					&dev_attr_pid))
+		if(class_device_create_file(&gnbd_dev[i].class_dev,
+					&class_device_attr_pid))
 			goto out_remove_file;
-		if(device_create_file(&gnbd_dev[i].class_dev,
-					&dev_attr_server))
+		if(class_device_create_file(&gnbd_dev[i].class_dev,
+					&class_device_attr_server))
 			goto out_remove_file;
-		if(device_create_file(&gnbd_dev[i].class_dev,
-					&dev_attr_name))
+		if(class_device_create_file(&gnbd_dev[i].class_dev,
+					&class_device_attr_name))
 			goto out_remove_file;
-		if(device_create_file(&gnbd_dev[i].class_dev,
-					&dev_attr_sectors))
+		if(class_device_create_file(&gnbd_dev[i].class_dev,
+					&class_device_attr_sectors))
 			goto out_remove_file;
-		if(device_create_file(&gnbd_dev[i].class_dev,
-					&dev_attr_usage))
+		if(class_device_create_file(&gnbd_dev[i].class_dev,
+					&class_device_attr_usage))
 			goto out_remove_file;
-		if(device_create_file(&gnbd_dev[i].class_dev,
-					&dev_attr_flags))
+		if(class_device_create_file(&gnbd_dev[i].class_dev,
+					&class_device_attr_flags))
 			goto out_remove_file;
-		if(device_create_file(&gnbd_dev[i].class_dev,
-					&dev_attr_waittime))
+		if(class_device_create_file(&gnbd_dev[i].class_dev,
+					&class_device_attr_waittime))
 			goto out_remove_file;
-		if(device_create_file(&gnbd_dev[i].class_dev,
-					&dev_attr_connected))
+		if(class_device_create_file(&gnbd_dev[i].class_dev,
+					&class_device_attr_connected))
 			goto out_remove_file;
 		disk->major = major_nr;
 		disk->first_minor = i;
@@ -1067,11 +1068,11 @@
 out_remove_disk:
 	del_gendisk(gnbd_dev[i].disk);
 out_remove_file:
-	device_unregister(&gnbd_dev[i].class_dev);
+	class_device_unregister(&gnbd_dev[i].class_dev);
 out_unregister_class:
 	while(i--){
 		del_gendisk(gnbd_dev[i].disk);
-		device_unregister(&gnbd_dev[i].class_dev);
+		class_device_unregister(&gnbd_dev[i].class_dev);
 	}
 	i = MAX_GNBD;
 	class_unregister(&gnbd_class);
@@ -1092,7 +1093,7 @@
 	gnbd_ctl_cleanup();
 	for (i = 0; i < MAX_GNBD; i++) {
 		struct gendisk *disk = gnbd_dev[i].disk;
-		device_unregister(&gnbd_dev[i].class_dev);
+		class_device_unregister(&gnbd_dev[i].class_dev);
 		if (disk) {
 			del_gendisk(disk);
 			blk_cleanup_queue(disk->queue);
diff -Naurd cluster-2.03.07.orig/gnbd-kernel/src/gnbd.h cluster-2.03.07/gnbd-kernel/src/gnbd.h
--- cluster-2.03.07.orig/gnbd-kernel/src/gnbd.h	2008-08-12 16:14:36.000000000 +0200
+++ cluster-2.03.07/gnbd-kernel/src/gnbd.h	2008-08-14 12:38:51.000000000 +0200
@@ -15,7 +15,7 @@
 	GNBD_CMD_PING = 3
 };
 
-#define gnbd_cmd(req) ((req)->__cmd[0])
+#define gnbd_cmd(req) ((req)->cmd[0])
 #define MAX_GNBD 128
 
 /* values for flags field */
@@ -37,7 +37,7 @@
 	pid_t receiver_pid;
 	struct semaphore do_it_lock;
 	int open_count;
-	struct device class_dev;
+	struct class_device class_dev;
 	unsigned short int server_port;
 	char *server_name;
 	char name[32];

userland-2.6.26.diff:

--- NEW FILE userland-2.6.26.diff ---
diff -Naurd cluster-2.03.07.orig/dlm/include/linux/dlmconstants.h cluster-2.03.07/dlm/include/linux/dlmconstants.h
--- cluster-2.03.07.orig/dlm/include/linux/dlmconstants.h	1970-01-01 01:00:00.000000000 +0100
+++ cluster-2.03.07/dlm/include/linux/dlmconstants.h	2008-08-14 13:44:59.000000000 +0200
@@ -0,0 +1,163 @@
+/******************************************************************************
+*******************************************************************************
+**
+**  Copyright (C) Sistina Software, Inc.  1997-2003  All rights reserved.
+**  Copyright (C) 2004-2007 Red Hat, Inc.  All rights reserved.
+**
+**  This copyrighted material is made available to anyone wishing to use,
+**  modify, copy, or redistribute it subject to the terms and conditions
+**  of the GNU General Public License v.2.
+**
+*******************************************************************************
+******************************************************************************/
+
+#ifndef __DLMCONSTANTS_DOT_H__
+#define __DLMCONSTANTS_DOT_H__
+
+/*
+ * Constants used by DLM interface.
+ */
+
+#define DLM_LOCKSPACE_LEN       64
+#define DLM_RESNAME_MAXLEN      64
+
+
+/*
+ * Lock Modes
+ */
+
+#define DLM_LOCK_IV		(-1)	/* invalid */
+#define DLM_LOCK_NL		0	/* null */
+#define DLM_LOCK_CR		1	/* concurrent read */
+#define DLM_LOCK_CW		2	/* concurrent write */
+#define DLM_LOCK_PR		3	/* protected read */
+#define DLM_LOCK_PW		4	/* protected write */
+#define DLM_LOCK_EX		5	/* exclusive */
+
+
+/*
+ * Flags to dlm_lock
+ *
+ * DLM_LKF_NOQUEUE
+ *
+ * Do not queue the lock request on the wait queue if it cannot be granted
+ * immediately.  If the lock cannot be granted because of this flag, DLM will
+ * either return -EAGAIN from the dlm_lock call or will return 0 from
+ * dlm_lock and -EAGAIN in the lock status block when the AST is executed.
+ *
+ * DLM_LKF_CANCEL
+ *
+ * Used to cancel a pending lock request or conversion.  A converting lock is
+ * returned to its previously granted mode.
+ *
+ * DLM_LKF_CONVERT
+ *
+ * Indicates a lock conversion request.  For conversions the name and namelen
+ * are ignored and the lock ID in the LKSB is used to identify the lock.
+ *
+ * DLM_LKF_VALBLK
+ *
+ * Requests DLM to return the current contents of the lock value block in the
+ * lock status block.  When this flag is set in a lock conversion from PW or EX
+ * modes, DLM assigns the value specified in the lock status block to the lock
+ * value block of the lock resource.  The LVB is a DLM_LVB_LEN size array
+ * containing application-specific information.
+ *
+ * DLM_LKF_QUECVT
+ *
+ * Force a conversion request to be queued, even if it is compatible with
+ * the granted modes of other locks on the same resource.
+ *
+ * DLM_LKF_IVVALBLK
+ *
+ * Invalidate the lock value block.
+ *
+ * DLM_LKF_CONVDEADLK
+ *
+ * Allows the dlm to resolve conversion deadlocks internally by demoting the
+ * granted mode of a converting lock to NL.  The DLM_SBF_DEMOTED flag is
+ * returned for a conversion that's been effected by this.
+ *
+ * DLM_LKF_PERSISTENT
+ *
+ * Only relevant to locks originating in userspace.  A persistent lock will not
+ * be removed if the process holding the lock exits.
+ *
+ * DLM_LKF_NODLCKWT
+ *
+ * Do not cancel the lock if it gets into conversion deadlock.
+ * Exclude this lock from being monitored due to DLM_LSFL_TIMEWARN.
+ *
+ * DLM_LKF_NODLCKBLK
+ *
+ * net yet implemented
+ *
+ * DLM_LKF_EXPEDITE
+ *
+ * Used only with new requests for NL mode locks.  Tells the lock manager
+ * to grant the lock, ignoring other locks in convert and wait queues.
+ *
+ * DLM_LKF_NOQUEUEBAST
+ *
+ * Send blocking AST's before returning -EAGAIN to the caller.  It is only
+ * used along with the NOQUEUE flag.  Blocking AST's are not sent for failed
+ * NOQUEUE requests otherwise.
+ *
+ * DLM_LKF_HEADQUE
+ *
+ * Add a lock to the head of the convert or wait queue rather than the tail.
+ *
+ * DLM_LKF_NOORDER
+ *
+ * Disregard the standard grant order rules and grant a lock as soon as it
+ * is compatible with other granted locks.
+ *
+ * DLM_LKF_ORPHAN
+ *
+ * not yet implemented
+ *
+ * DLM_LKF_ALTPR
+ *
+ * If the requested mode cannot be granted immediately, try to grant the lock
+ * in PR mode instead.  If this alternate mode is granted instead of the
+ * requested mode, DLM_SBF_ALTMODE is returned in the lksb.
+ *
+ * DLM_LKF_ALTCW
+ *
+ * The same as ALTPR, but the alternate mode is CW.
+ *
+ * DLM_LKF_FORCEUNLOCK
+ *
+ * Unlock the lock even if it is converting or waiting or has sublocks.
+ * Only really for use by the userland device.c code.
+ *
+ */
+
+#define DLM_LKF_NOQUEUE		0x00000001
+#define DLM_LKF_CANCEL		0x00000002
+#define DLM_LKF_CONVERT		0x00000004
+#define DLM_LKF_VALBLK		0x00000008
+#define DLM_LKF_QUECVT		0x00000010
+#define DLM_LKF_IVVALBLK	0x00000020
+#define DLM_LKF_CONVDEADLK	0x00000040
+#define DLM_LKF_PERSISTENT	0x00000080
+#define DLM_LKF_NODLCKWT	0x00000100
+#define DLM_LKF_NODLCKBLK	0x00000200
+#define DLM_LKF_EXPEDITE	0x00000400
+#define DLM_LKF_NOQUEUEBAST	0x00000800
+#define DLM_LKF_HEADQUE		0x00001000
+#define DLM_LKF_NOORDER		0x00002000
+#define DLM_LKF_ORPHAN		0x00004000
+#define DLM_LKF_ALTPR		0x00008000
+#define DLM_LKF_ALTCW		0x00010000
+#define DLM_LKF_FORCEUNLOCK	0x00020000
+#define DLM_LKF_TIMEOUT		0x00040000
+
+/*
+ * Some return codes that are not in errno.h
+ */
+
+#define DLM_ECANCEL		0x10001
+#define DLM_EUNLOCK		0x10002
+
+#endif  /* __DLMCONSTANTS_DOT_H__ */
diff -Naurd cluster-2.03.07.orig/dlm/include/linux/dlm_device.h cluster-2.03.07/dlm/include/linux/dlm_device.h
--- cluster-2.03.07.orig/dlm/include/linux/dlm_device.h	1970-01-01 01:00:00.000000000 +0100
+++ cluster-2.03.07/dlm/include/linux/dlm_device.h	2008-08-14 13:44:59.000000000 +0200
@@ -0,0 +1,112 @@
+/******************************************************************************
+*******************************************************************************
+**
+**  Copyright (C) Sistina Software, Inc.  1997-2003  All rights reserved.
+**  Copyright (C) 2004-2007 Red Hat, Inc.  All rights reserved.
+**
+**  This copyrighted material is made available to anyone wishing to use,
+**  modify, copy, or redistribute it subject to the terms and conditions
+**  of the GNU General Public License v.2.
+**
+*******************************************************************************
+******************************************************************************/
+
+#ifndef _LINUX_DLM_DEVICE_H
+#define _LINUX_DLM_DEVICE_H
+
+/* This is the device interface for dlm, most users will use a library
+ * interface.
+ */
+
+#include <linux/dlm.h>
+#include <linux/types.h>
+
+#ifndef __user
+#define __user
+#endif
+
+#define DLM_USER_LVB_LEN	32
+
+/* Version of the device interface */
+#define DLM_DEVICE_VERSION_MAJOR 6
+#define DLM_DEVICE_VERSION_MINOR 0
+#define DLM_DEVICE_VERSION_PATCH 0
+
+/* struct passed to the lock write */
+struct dlm_lock_params {
+	__u8 mode;
+	__u8 namelen;
+	__u16 unused;
+	__u32 flags;
+	__u32 lkid;
+	__u32 parent;
+	__u64 xid;
+	__u64 timeout;
+	void __user *castparam;
+	void __user *castaddr;
+	void __user *bastparam;
+	void __user *bastaddr;
+	struct dlm_lksb __user *lksb;
+	char lvb[DLM_USER_LVB_LEN];
+	char name[0];
+};
+
+struct dlm_lspace_params {
+	__u32 flags;
+	__u32 minor;
+	char name[0];
+};
+
+struct dlm_purge_params {
+	__u32 nodeid;
+	__u32 pid;
+};
+
+struct dlm_write_request {
+	__u32 version[3];
+	__u8 cmd;
+	__u8 is64bit;
+	__u8 unused[2];
+
+	union  {
+		struct dlm_lock_params   lock;
+		struct dlm_lspace_params lspace;
+		struct dlm_purge_params  purge;
+	} i;
+};
+
+struct dlm_device_version {
+	__u32 version[3];
+};
+
+/* struct read from the "device" fd,
+   consists mainly of userspace pointers for the library to use */
+
+struct dlm_lock_result {
+	__u32 version[3];
+	__u32 length;
+	void __user * user_astaddr;
+	void __user * user_astparam;
+	struct dlm_lksb __user * user_lksb;
+	struct dlm_lksb lksb;
+	__u8 bast_mode;
+	__u8 unused[3];
+	/* Offsets may be zero if no data is present */
+	__u32 lvb_offset;
+};
+
+/* Commands passed to the device */
+#define DLM_USER_LOCK         1
+#define DLM_USER_UNLOCK       2
+#define DLM_USER_QUERY        3
+#define DLM_USER_CREATE_LOCKSPACE  4
+#define DLM_USER_REMOVE_LOCKSPACE  5
+#define DLM_USER_PURGE        6
+#define DLM_USER_DEADLOCK     7
+
+/* Lockspace flags */
+#define DLM_USER_LSFLG_AUTOFREE   1
+#define DLM_USER_LSFLG_FORCEFREE  2
+
+#endif
+
diff -Naurd cluster-2.03.07.orig/dlm/include/linux/dlm.h cluster-2.03.07/dlm/include/linux/dlm.h
--- cluster-2.03.07.orig/dlm/include/linux/dlm.h	1970-01-01 01:00:00.000000000 +0100
+++ cluster-2.03.07/dlm/include/linux/dlm.h	2008-08-14 13:44:59.000000000 +0200
@@ -0,0 +1,169 @@
+/******************************************************************************
+*******************************************************************************
+**
+**  Copyright (C) Sistina Software, Inc.  1997-2003  All rights reserved.
+**  Copyright (C) 2004-2007 Red Hat, Inc.  All rights reserved.
+**
+**  This copyrighted material is made available to anyone wishing to use,
+**  modify, copy, or redistribute it subject to the terms and conditions
+**  of the GNU General Public License v.2.
+**
+*******************************************************************************
+******************************************************************************/
+
+#ifndef __DLM_DOT_H__
+#define __DLM_DOT_H__
+
+/*
+ * Interface to Distributed Lock Manager (DLM)
+ * routines and structures to use DLM lockspaces
+ */
+
+/* Lock levels and flags are here */
+#include <linux/dlmconstants.h>
+#include <linux/types.h>
+
+typedef void dlm_lockspace_t;
+
+/*
+ * Lock status block
+ *
+ * Use this structure to specify the contents of the lock value block.  For a
+ * conversion request, this structure is used to specify the lock ID of the
+ * lock.  DLM writes the status of the lock request and the lock ID assigned
+ * to the request in the lock status block.
+ *
+ * sb_lkid: the returned lock ID.  It is set on new (non-conversion) requests.
+ * It is available when dlm_lock returns.
+ *
+ * sb_lvbptr: saves or returns the contents of the lock's LVB according to rules
+ * shown for the DLM_LKF_VALBLK flag.
+ *
+ * sb_flags: DLM_SBF_DEMOTED is returned if in the process of promoting a lock,
+ * it was first demoted to NL to avoid conversion deadlock.
+ * DLM_SBF_VALNOTVALID is returned if the resource's LVB is marked invalid.
+ *
+ * sb_status: the returned status of the lock request set prior to AST
+ * execution.  Possible return values:
+ *
+ * 0 if lock request was successful
+ * -EAGAIN if request would block and is flagged DLM_LKF_NOQUEUE
+ * -ENOMEM if there is no memory to process request
+ * -EINVAL if there are invalid parameters
+ * -DLM_EUNLOCK if unlock request was successful
+ * -DLM_ECANCEL if a cancel completed successfully
+ */
+
+#define DLM_SBF_DEMOTED		0x01
+#define DLM_SBF_VALNOTVALID	0x02
+#define DLM_SBF_ALTMODE		0x04
+
+struct dlm_lksb {
+	int 	 sb_status;
+	__u32	 sb_lkid;
+	char 	 sb_flags;
+	char *	 sb_lvbptr;
+};
+
+#define DLM_LSFL_NODIR		0x00000001
+#define DLM_LSFL_TIMEWARN	0x00000002
+#define DLM_LSFL_FS     	0x00000004
+
+#ifdef __KERNEL__
+
+/*
+ * dlm_new_lockspace
+ *
+ * Starts a lockspace with the given name.  If the named lockspace exists in
+ * the cluster, the calling node joins it.
+ */
+
+int dlm_new_lockspace(char *name, int namelen, dlm_lockspace_t **lockspace,
+		      uint32_t flags, int lvblen);
+
+/*
+ * dlm_release_lockspace
+ *
+ * Stop a lockspace.
+ */
+
+int dlm_release_lockspace(dlm_lockspace_t *lockspace, int force);
+
+/*
+ * dlm_lock
+ *
+ * Make an asyncronous request to acquire or convert a lock on a named
+ * resource.
+ *
+ * lockspace: context for the request
+ * mode: the requested mode of the lock (DLM_LOCK_)
+ * lksb: lock status block for input and async return values
+ * flags: input flags (DLM_LKF_)
+ * name: name of the resource to lock, can be binary
+ * namelen: the length in bytes of the resource name (MAX_RESNAME_LEN)
+ * parent: the lock ID of a parent lock or 0 if none
+ * lockast: function DLM executes when it completes processing the request
+ * astarg: argument passed to lockast and bast functions
+ * bast: function DLM executes when this lock later blocks another request
+ *
+ * Returns:
+ * 0 if request is successfully queued for processing
+ * -EINVAL if any input parameters are invalid
+ * -EAGAIN if request would block and is flagged DLM_LKF_NOQUEUE
+ * -ENOMEM if there is no memory to process request
+ * -ENOTCONN if there is a communication error
+ *
+ * If the call to dlm_lock returns an error then the operation has failed and
+ * the AST routine will not be called.  If dlm_lock returns 0 it is still
+ * possible that the lock operation will fail. The AST routine will be called
+ * when the locking is complete and the status is returned in the lksb.
+ *
+ * If the AST routines or parameter are passed to a conversion operation then
+ * they will overwrite those values that were passed to a previous dlm_lock
+ * call.
+ *
+ * AST routines should not block (at least not for long), but may make
+ * any locking calls they please.
+ */
+
+int dlm_lock(dlm_lockspace_t *lockspace,
+	     int mode,
+	     struct dlm_lksb *lksb,
+	     uint32_t flags,
+	     void *name,
+	     unsigned int namelen,
+	     uint32_t parent_lkid,
+	     void (*lockast) (void *astarg),
+	     void *astarg,
+	     void (*bast) (void *astarg, int mode));
+
+/*
+ * dlm_unlock
+ *
+ * Asynchronously release a lock on a resource.  The AST routine is called
+ * when the resource is successfully unlocked.
+ *
+ * lockspace: context for the request
+ * lkid: the lock ID as returned in the lksb
+ * flags: input flags (DLM_LKF_)
+ * lksb: if NULL the lksb parameter passed to last lock request is used
+ * astarg: the arg used with the completion ast for the unlock
+ *
+ * Returns:
+ * 0 if request is successfully queued for processing
+ * -EINVAL if any input parameters are invalid
+ * -ENOTEMPTY if the lock still has sublocks
+ * -EBUSY if the lock is waiting for a remote lock operation
+ * -ENOTCONN if there is a communication error
+ */
+
+int dlm_unlock(dlm_lockspace_t *lockspace,
+	       uint32_t lkid,
+	       uint32_t flags,
+	       struct dlm_lksb *lksb,
+	       void *astarg);
+
+#endif				/* __KERNEL__ */
+
+#endif				/* __DLM_DOT_H__ */
+
diff -Naurd cluster-2.03.07.orig/dlm/include/linux/dlm_netlink.h cluster-2.03.07/dlm/include/linux/dlm_netlink.h
--- cluster-2.03.07.orig/dlm/include/linux/dlm_netlink.h	1970-01-01 01:00:00.000000000 +0100
+++ cluster-2.03.07/dlm/include/linux/dlm_netlink.h	2008-08-14 13:44:59.000000000 +0200
@@ -0,0 +1,56 @@
+/*
+ * Copyright (C) 2007 Red Hat, Inc.  All rights reserved.
+ *
+ * This copyrighted material is made available to anyone wishing to use,
+ * modify, copy, or redistribute it subject to the terms and conditions
+ * of the GNU General Public License v.2.
+ */
+
+#ifndef _DLM_NETLINK_H
+#define _DLM_NETLINK_H
+
+enum {
+	DLM_STATUS_WAITING = 1,
+	DLM_STATUS_GRANTED = 2,
+	DLM_STATUS_CONVERT = 3,
+};
+
+#define DLM_LOCK_DATA_VERSION 1
+
+struct dlm_lock_data {
+	uint16_t version;
+	uint32_t lockspace_id;
+	int nodeid;
+	int ownpid;
+	uint32_t id;
+	uint32_t remid;
+	uint64_t xid;
+	int8_t status;
+	int8_t grmode;
+	int8_t rqmode;
+	unsigned long timestamp;
+	int resource_namelen;
+	char resource_name[DLM_RESNAME_MAXLEN];
+};
+
+enum {
+	DLM_CMD_UNSPEC = 0,
+	DLM_CMD_HELLO,		/* user->kernel */
+	DLM_CMD_TIMEOUT,	/* kernel->user */
+	__DLM_CMD_MAX,
+};
+
+#define DLM_CMD_MAX (__DLM_CMD_MAX - 1)
+
+enum {
+	DLM_TYPE_UNSPEC = 0,
+	DLM_TYPE_LOCK,
+	__DLM_TYPE_MAX,
+};
+
+#define DLM_TYPE_MAX (__DLM_TYPE_MAX - 1)
+
+#define DLM_GENL_VERSION 0x1
+#define DLM_GENL_NAME "DLM"
+
+#endif /* _DLM_NETLINK_H */
diff -Naurd cluster-2.03.07.orig/dlm/include/linux/dlm_plock.h cluster-2.03.07/dlm/include/linux/dlm_plock.h
--- cluster-2.03.07.orig/dlm/include/linux/dlm_plock.h	1970-01-01 01:00:00.000000000 +0100
+++ cluster-2.03.07/dlm/include/linux/dlm_plock.h	2008-08-14 13:44:59.000000000 +0200
@@ -0,0 +1,50 @@
+/*
+ * Copyright (C) 2005-2008 Red Hat, Inc.  All rights reserved.
+ *
+ * This copyrighted material is made available to anyone wishing to use,
+ * modify, copy, or redistribute it subject to the terms and conditions
+ * of the GNU General Public License v.2.
+ */
+
+#ifndef __DLM_PLOCK_DOT_H__
+#define __DLM_PLOCK_DOT_H__
+
+#define DLM_PLOCK_MISC_NAME		"dlm_plock"
+
+#define DLM_PLOCK_VERSION_MAJOR	1
+#define DLM_PLOCK_VERSION_MINOR	1
+#define DLM_PLOCK_VERSION_PATCH	0
+
+enum {
+	DLM_PLOCK_OP_LOCK = 1,
+	DLM_PLOCK_OP_UNLOCK,
+	DLM_PLOCK_OP_GET,
+};
+
+struct dlm_plock_info {
+	__u32 version[3];
+	__u8 optype;
+	__u8 ex;
+	__u8 wait;
+	__u8 pad;
+	__u32 pid;
+	__s32 nodeid;
+	__s32 rv;
+	__u32 fsid;
+	__u64 number;
+	__u64 start;
+	__u64 end;
+	__u64 owner;
+};
+
+#ifdef __KERNEL__
+int dlm_posix_lock(dlm_lockspace_t *lockspace, u64 number, struct file *file,
+		int cmd, struct file_lock *fl);
+int dlm_posix_unlock(dlm_lockspace_t *lockspace, u64 number, struct file *file,
+		struct file_lock *fl);
+int dlm_posix_get(dlm_lockspace_t *lockspace, u64 number, struct file *file,
+		struct file_lock *fl);
+#endif /* __KERNEL__ */
+
+#endif
+
diff -Naurd cluster-2.03.07.orig/group/gfs_controld/Makefile cluster-2.03.07/group/gfs_controld/Makefile
--- cluster-2.03.07.orig/group/gfs_controld/Makefile	2008-08-12 16:14:36.000000000 +0200
+++ cluster-2.03.07/group/gfs_controld/Makefile	2008-08-14 13:46:40.000000000 +0200
@@ -17,6 +17,7 @@
 	plock.o \
 	recover.o
 
+CFLAGS += -I$(S)/../../dlm/include/
 CFLAGS += -I${ccsincdir} -I${cmanincdir} -I${openaisincdir}
 CFLAGS += -I${KERNEL_SRC}/include/
 CFLAGS += -I$(S)/../lib/ -I$(S)/../include/
diff -Naurd cluster-2.03.07.orig/group/tool/Makefile cluster-2.03.07/group/tool/Makefile
--- cluster-2.03.07.orig/group/tool/Makefile	2008-08-12 16:14:36.000000000 +0200
+++ cluster-2.03.07/group/tool/Makefile	2008-08-14 13:45:16.000000000 +0200
@@ -12,6 +12,7 @@
 
 OBJS=	main.o
 
+CFLAGS += -I$(S)/../../dlm/include/
 CFLAGS += -I$(S) -I$(S)/../daemon/ -I$(S)/../lib/
 CFLAGS += -I${incdir}
 


Index: .cvsignore
===================================================================
RCS file: /cvs/pkgs/rpms/rgmanager/F-9/.cvsignore,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -r1.17 -r1.18
--- .cvsignore	14 Jul 2008 07:00:46 -0000	1.17
+++ .cvsignore	14 Aug 2008 12:39:37 -0000	1.18
@@ -1 +1 @@
-cluster-2.03.05.tar.gz
+cluster-2.03.07.tar.gz


Index: rgmanager.spec
===================================================================
RCS file: /cvs/pkgs/rpms/rgmanager/F-9/rgmanager.spec,v
retrieving revision 1.47
retrieving revision 1.48
diff -u -r1.47 -r1.48
--- rgmanager.spec	14 Jul 2008 07:00:46 -0000	1.47
+++ rgmanager.spec	14 Aug 2008 12:39:37 -0000	1.48
@@ -12,12 +12,15 @@
 
 Name: rgmanager
 Summary: Open Source HA Resource Group Failover for Red Hat Enterprise Linux
-Version: 2.03.05
+Version: 2.03.07
 Release: 1%{?alphatag:.%{alphatag}}%{?dist}
 License: GPLv2+ and LGPLv2+
 Group: System Environment/Base
 URL: http://sources.redhat.com/cluster/wiki/
 Source0: ftp://sources.redhat.com/pub/cluster/releases/cluster-%{version}.tar.gz
+Patch0: kernel-2.6.25.diff
+Patch1: userland-2.6.26.diff
+
 Requires: chkconfig initscripts glibc ncurses bash grep sed gawk
 Requires: cman >= 2.03.03
 Requires: net-tools mount e2fsprogs
@@ -36,6 +39,8 @@
 
 %prep
 %setup -q -n cluster-%{version}
+%patch0 -p1
+%patch1 -p1
 
 %build
 # for legacy reasons, all binaries have always been installed in /sbin
@@ -71,7 +76,7 @@
 
 %files
 %defattr(-,root,root,-)
-%doc doc/* rgmanager/README rgmanager/errors.txt
+%doc doc/COPYING.* doc/COPYRIGHT doc/README.licence doc/*.txt rgmanager/README rgmanager/errors.txt
 %{_sysconfdir}/rc.d/init.d/rgmanager
 /usr/sbin/clu*
 /usr/sbin/rg_test
@@ -79,6 +84,16 @@
 %{_mandir}/man8/clu*
 
 %changelog
+* Thu Aug 14 2008 Fabio M. Di Nitto <fdinitto at redhat.com> - 2.03.07-1
+- New upstream release
+- Fix rgmanager startup locking issues
+- Apply patch to include kernel headers from 2.6.26 required to build
+  userland. Userland will run in 2.6.25 compatibility mode
+- Apply patch to keep kernel modules at 2.6.25 (upstream is at 2.6.26)
+  (this patch is purely cosmetic since we don't build kernel modules
+  but keep the source in sync is Good (tm))
+- Cleanup packaging for installed docs and file permissions
+
 * Mon Jul 14 2008 Fabio M. Di Nitto <fdinitto at redhat.com> - 2.03.05-1
 - New upstream release
 - Cleanup installed doc after upstream


Index: sources
===================================================================
RCS file: /cvs/pkgs/rpms/rgmanager/F-9/sources,v
retrieving revision 1.26
retrieving revision 1.27
diff -u -r1.26 -r1.27
--- sources	14 Jul 2008 07:00:46 -0000	1.26
+++ sources	14 Aug 2008 12:39:37 -0000	1.27
@@ -1 +1 @@
-b1bbd928d21e47ffff2417809f9016ca  cluster-2.03.05.tar.gz
+bb5d23e582bedfc41cac121e35f594de  cluster-2.03.07.tar.gz




More information about the fedora-extras-commits mailing list
diff -Naurd cluster-2.03.07.orig/gfs-kernel/src/gfs/ops_super.c cluster-2.03.07/gfs-kernel/src/gfs/ops_super.c
--- cluster-2.03.07.orig/gfs-kernel/src/gfs/ops_super.c	2008-08-12 16:14:36.000000000 +0200
+++ cluster-2.03.07/gfs-kernel/src/gfs/ops_super.c	2008-08-14 12:39:08.000000000 +0200
@@ -49,7 +49,7 @@
 }
 
 /**
  * gfs_drop_inode - drop an inode
  * @inode: The inode
  *
  * If i_nlink is zero, any dirty data for the inode is thrown away.
@@ -58,7 +58,7 @@
  */
 
 static void
-gfs_drop_inode(struct inode *inode)
+gfs_put_inode(struct inode *inode)
 {
 	struct gfs_sbd *sdp = get_v2sdp(inode->i_sb);
 	struct gfs_inode *ip = get_v2ip(inode);
@@ -70,7 +70,6 @@
 	    S_ISREG(inode->i_mode) &&
 	    !sdp->sd_args.ar_localcaching)
 		gfs_sync_page_i(inode, DIO_START | DIO_WAIT);
-	generic_drop_inode(inode);
 }
 
 /**
@@ -443,7 +442,7 @@
 
 struct super_operations gfs_super_ops = {
 	.write_inode = gfs_write_inode,
-	.drop_inode = gfs_drop_inode,
+	.put_inode = gfs_put_inode,
 	.put_super = gfs_put_super,
 	.write_super = gfs_write_super,
 	.write_super_lockfs = gfs_write_super_lockfs,
@@ -49,7 +49,7 @@
 
 /**
- * gfs_drop_inode - drop an inode
+ * gfs_put_inode - put an inode
  * @inode: The inode
  *